@@ -262,6 +262,10 @@ The guest is paused at admin request
 
 The guest is paused due to the watchdog
 
+=item Sys::Virt::Domain::STATE_PAUSED_SHUTTING_DOWN
+
+The guest is paused while domain shutdown takes place
+
 =item Sys::Virt::Domain::STATE_RUNNING_BOOTED
 
 The guest is running after being booted
@@ -710,6 +714,12 @@ Set the maximum allowed bandwidth during migration of the guest.
 The C<bandwidth> parameter is measured in kilobytes/second.
 The C<$flags> parameter is currently unused and defaults to zero.
 
+=item $bandwidth = $dom->migrate_get_max_speed($flag)
+
+Get the maximum allowed bandwidth during migration fo the guest.
+The returned <bandwidth> value is measured in kilobytes/second.
+The C<$flags> parameter is currently unused and defaults to zero.
+
 =item $dom->inject_nmi($flags)
 
 Trigger an NMI in the guest virtual machine. The C<$flags> parameter
@@ -799,7 +809,7 @@ sub list_snapshots {
     my @snapshots;
     foreach my $name (@names) {
 	eval {
-	    push @snapshots, Sys::Virt::Domain->_new(connection => $self, name => $name);
+	    push @snapshots, Sys::Virt::DomainSnapshot->_new(domain => $self, name => $name);
 	};
 	if ($@) {
 	    # nada - snapshot went away before we could look it up
@@ -809,6 +819,20 @@ sub list_snapshots {
 }
 
 
+=item my $snapshot = $dom->get_snapshot_by_name($name)
+
+Return the domain snapshot with a name of C<$name>. The returned object is
+an instance of the L<Sys::Virt::DomainSnapshot> class.
+
+=cut
+
+sub get_snapshot_by_name {
+    my $self = shift;
+    my $name = shift;
+
+    return Sys::Virt::DomainSnapshot->_new(domain => $self, name => $name);
+}
+
 =item $dom->has_current_snapshot()
 
 Returns a true value if the domain has a currently active snapshot
@@ -817,6 +841,22 @@ Returns a true value if the domain has a currently active snapshot
 
 Returns the currently active snapshot for the domain.
 
+=item $snapshot = $dom->create_snapshot($xml[, $flags])
+
+Create a new snapshot from the C<$xml>.
+
+=cut
+
+sub create_snapshot {
+    my $self = shift;
+    my $xml = shift;
+    my $flags = shift;
+
+    my $snapshot = Sys::Virt::DomainSnapshot->_new(domain => $self, xml => $xml, flags => $flags);
+
+    return $snapshot;
+}
+
 =over 4
 
 =item type
@@ -967,6 +1007,10 @@ Automatically destroy the guest when the connection is closed (or fails)
 
 Do not use OS I/O cache if starting a domain with a saved state image
 
+=item Sys::Virt::Domain::START_FORCE_BOOT
+
+Boot the guest, even if there was a saved snapshot
+
 =back
 
 
@@ -1013,6 +1057,12 @@ The USB HID keycode set
 
 The Windows keycode set
 
+=item Sys::Virt::Domain::KEYCODE_SET_RFB
+
+The XT keycode set, with the extended scancodes using the
+high bit of the first byte, instead of the low bit of the
+second byte.
+
 =back
 
 =head2 MEMORY PEEK
@@ -1204,6 +1254,11 @@ domain configurations
 Also remove any managed save image when undefining the virtual
 domain
 
+=item Sys::Virt::Domain::UNDEFINE_SNAPSHOTS_METADATA
+
+Also remove any snapshot metadata when undefining the virtual
+domain.
+
 =back
 
 =head2 JOB TYPES
@@ -1341,6 +1396,10 @@ emitted on the destination host.
 
 The domain resumed because the admin unpaused it.
 
+=item Sys::Virt::Domain::EVENT_RESUMED_FROM_SNAPSHOT
+
+The domain resumed becuase it was restored from a snapshot
+
 =back
 
 =item Sys::Virt::Domain::EVENT_STARTED
@@ -1412,6 +1471,23 @@ The domain has been suspended due to offline migration
 The domain has been suspended due to administrator pause
 request.
 
+=item Sys::Virt::Domain::EVENT_SUSPENDED_IOERROR
+
+The domain has been suspended due to a block device I/O
+error.
+
+=item Sys::Virt::Domain::EVENT_SUSPENDED_FROM_SNAPSHOT
+
+The domain has been suspended due to resume from snapshot
+
+=item Sys::Virt::Domain::EVENT_SUSPENDED_WATCHDOG
+
+The domain has been suspended due to the watchdog triggering
+
+=item Sys::Virt::Domain::EVENT_SUSPENDED_RESTORED
+
+The domain has been suspended due to restore from saved state
+
 =back
 
 =item Sys::Virt::Domain::EVENT_UNDEFINED
@@ -1606,6 +1682,16 @@ virtual machines
 
 Do not use OS I/O cache when saving state.
 
+=item Sys::Virt::Domain::SAVE_PAUSED
+
+Mark the saved state as paused to prevent the guest CPUs
+starting upon restore.
+
+=item Sys::Virt::Domain::SAVE_RUNNING
+
+Mark the saved state as running to allow the guest CPUs
+to start upon restore.
+
 =back
 
 =head2 DOMAIN CORE DUMP CONSTANTS
